# ==========================================================================
#
# ZoneMinder EasyN IP Control Protocol Module, $Date: 2012-02-04 15:19:10 +0100 (Sat, 04 Feb 2012) $, $Revision: 0001 $
# Copyright (C) 2001-2008  Philip Coombes
# Modified for use with EasyN HS-696L-B0L7 IP Camera by Erik Weinans
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# ==========================================================================
#
# This module contains the implementation of the Panasonic IP camera control
# protocol
#
package ZoneMinder::Control::EasyN;

use 5.006;
use strict;
use warnings;

require ZoneMinder::Base;
require ZoneMinder::Control;

our @ISA = qw(ZoneMinder::Control);

our $VERSION = $ZoneMinder::Base::VERSION;

# ==========================================================================
#
# EasyN HS-696L-B0L7 IP Control Protocol
#
# ==========================================================================

use ZoneMinder::Logger qw(:all);
use ZoneMinder::Config qw(:all);

use Time::HiRes qw( usleep );

sub new
{
    my $class = shift;
    my $id = shift;
    my $self = ZoneMinder::Control->new( $id );
    bless( $self, $class );
    srand( time() );
    return $self;
}

our $AUTOLOAD;

sub AUTOLOAD
{
    my $self = shift;
    my $class = ref($self) || croak( "$self not object" );
    my $name = $AUTOLOAD;
    $name =~ s/.*://;
    if ( exists($self->{$name}) )
    {
        return( $self->{$name} );
    }
    Fatal( "Can't access $name member of object of class $class" );
}

sub open
{
    my $self = shift;

    $self->loadMonitor();

    use LWP::UserAgent;
    $self->{ua} = LWP::UserAgent->new;
    $self->{ua}->agent( "ZoneMinder Control Agent/".ZM_VERSION );

    $self->{state} = 'open';
}

sub close
{
    my $self = shift;
    $self->{state} = 'closed';
}

sub printMsg
{
    my $self = shift;
    my $msg = shift;
    my $msg_len = length($msg);

    Debug( $msg."[".$msg_len."]" );
}

sub sendCmd
{
    my $self = shift;
    my $cmd = shift;
    my $result = undef;

    printMsg( $cmd, "Tx" );

    my $req = HTTP::Request->new( GET=>"http://".$self->{Monitor}->{ControlAddress}."/$cmd" );
    my $res = $self->{ua}->request($req);

    if ( $res->is_success )
    {
        $result = !undef;
    }
    else
    {
        Error( "Error check failed: '".$res->status_line()."'" );
    }

    return( $result );
}

sub cameraReset
{
    my $self = shift;
    Debug( "Camera Reset" );
    my $cmd = "cgi-bin/hi3510/sysreboot.cgi";
    $self->sendCmd( $cmd );
}

sub Up
{
    my $self = shift;
    Debug( "Move Up" );
    my $cmd = "cgi-bin/ptzctrlup.cgi";
    $self->sendCmd( $cmd );
}

sub Down
{
    my $self = shift;
    Debug( "Move Down" );
    my $cmd = "cgi-bin/ptzctrldown.cgi";
    $self->sendCmd( $cmd );
}

sub Left
{
    my $self = shift;
    Debug( "Move Left" );
    my $cmd = "cgi-bin/ptzctrlleft.cgi";
    $self->sendCmd( $cmd );
}

sub Right
{
    my $self = shift;
    Debug( "Move Right" );
    my $cmd = "cgi-bin/ptzctrlright.cgi";
    $self->sendCmd( $cmd );
}

sub Tele
{
    my $self = shift;
    Debug( "Zoom Tele" );
    my $cmd = "cgi-bin/ptzctrlzoomin.cgi";
    $self->sendCmd( $cmd );
}

sub Wide
{
    my $self = shift;
    Debug( "Zoom Wide" );
    my $cmd = "cgi-bin/ptzctrlzoomout.cgi";
    $self->sendCmd( $cmd );
}

sub Near
{
    my $self = shift;
    Debug( "Focus Near" );
    my $cmd = "cgi-bin/hi3510/ptzctrl.cgi?-step=1"."&-act=focusin";
    printMsg( $cmd );
    $self->sendCmd( $cmd );
}

sub Far
{
    my $self = shift;
    Debug( "Focus Far" );
    my $cmd = "cgi-bin/hi3510/ptzctrl.cgi?-step=1&-act=focusout";
    $self->sendCmd( $cmd );
}

sub presetSet
{
    my $self = shift;
    my $params = shift;
    my $preset = $self->getParam( $params, 'preset' );
    Debug( "Set Preset $preset" );
    my $cmd = "cgi-bin/hi3510/preset.cgi?-act=set&-status=1&-number=$preset";
    $self->sendCmd( $cmd );
}

sub presetGoto
{
    my $self = shift;
    my $params = shift;
    my $preset = $self->getParam( $params, 'preset' );
    Debug( "Goto Preset $preset" );
    my $cmd = "cgi-bin/hi3510/preset.cgi?-act=goto&-number=$preset";
    $self->sendCmd( $cmd );
}

sub presetHome
{
    my $self = shift;
    Debug( "Home Preset" );
    my $cmd = "cgi-bin/hi3510/preset.cgi?-act=goto&-number=0";
    $self->sendCmd( $cmd );
}

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

ZoneMinder::Database - Perl extension for blah blah blah

=head1 SYNOPSIS

  use ZoneMinder::Database;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for ZoneMinder, created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.

=head2 EXPORT

None by default.



=head1 SEE ALSO

Mention other useful documentation such as the documentation of
related modules or operating system documentation (such as man pages
in UNIX), or any relevant external documentation such as RFCs or
standards.

If you have a mailing list set up for your module, mention it here.

If you have a web site set up for your module, mention it here.

=head1 AUTHOR

Philip Coombes, E<lt>philip.coombes@zoneminder.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2001-2008  Philip Coombes

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.3 or,
at your option, any later version of Perl 5 you may have available.

=cut


